package com.muyu.saas.datasource;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.common.core.utils.SpringUtils;

import com.muyu.saas.domain.model.DataSourceInfo;
import com.muyu.saas.domain.model.EnterPriseInfo;
import com.muyu.saas.factory.DruidDataSourceFactory;
import com.muyu.saas.role.DynamicDataSource;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 多数据源 ManyDataSource
 *
 * @author DeKangLiu
 * Date 2024/6/3 20:01
 */
@Component
@Log4j2
@AllArgsConstructor
public class ManyDataSource {

    @PostConstruct
    public void init(){
        new Thread(()->{
            try {
                Thread.sleep(10000);
            } catch (InterruptedException ignored) {}
            DruidDataSourceFactory druidDataSourceFactory= SpringUtils.getBean(DruidDataSourceFactory.class);
            DynamicDataSource dynamicDataSource= SpringUtils.getBean(DynamicDataSource.class);
            EnterPriseInfo enterPriseInfo = EnterPriseInfo.builder()
                    .entCode("liu_0605")
                    .ip("192.168.116.129")
                    .port(3309)
                    .build();

            DataSourceInfo dataSourceInfo = DataSourceInfo.hostAndPortBuild(enterPriseInfo.getEntCode(), enterPriseInfo.getIp(), enterPriseInfo.getPort());
            DruidDataSource druidDataSource = druidDataSourceFactory.create(dataSourceInfo);
            dynamicDataSource.put(dataSourceInfo.getKey(), druidDataSource);
        }).start();
    }


    private List<EnterPriseInfo> dataSourceInfoList(){
        List<EnterPriseInfo> list = new ArrayList<>();
        list.add(
                EnterPriseInfo.builder()
                        .entCode("liu_0608")
                        .ip("192.168.116.129")
                        .port(3310)
                        .build()
        );
        return list;
    }

    @Bean
    @Primary
    public DynamicDataSource dynamicDataSource(DruidDataSourceFactory druidDataSourceFactory) {

        //企业列表  企业CODE 端口 ip
        Map<Object, Object> dataSourceMap = new HashMap<>();
        dataSourceInfoList()
                .stream()
                .map(enterPriseInfo -> DataSourceInfo.hostAndPortBuild(enterPriseInfo.getEntCode(), enterPriseInfo.getIp(),enterPriseInfo.getPort()))
                .forEach(dataSourceInfo -> {
            dataSourceMap.put(dataSourceInfo.getKey(), druidDataSourceFactory.create(dataSourceInfo));
        });
        //设置动态数据源
        DynamicDataSource dynamicDataSource = new DynamicDataSource();
//        dynamicDataSource.setDefaultTargetDataSource(masterDataSource());
        dynamicDataSource.setTargetDataSources(dataSourceMap);
        //将数据源信息备份在defineTargetDataSources中
        dynamicDataSource.setDefineTargetDataSources(dataSourceMap);
        return dynamicDataSource;
    }
}
