package com.muyu.system.remote;

import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.system.domain.SysUser;
import com.muyu.system.remote.factory.RemoteSysUserFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 远程调用用户 RemoteSysUserService
 *
 * @author DeKangLiu
 * Date 2024/6/7 08:51
 */
@FeignClient(
        contextId = "remoteSysUserService",
        value = ServiceNameConstants.SYSTEM_SERVICE,
        fallbackFactory = RemoteSysUserFactory.class,
        path = "/user"
)
public interface RemoteSysUserService {
    /**
     * 新增用户服务
     * @param user
     * @return Result
     */
    @RequiresPermissions("system:user:add")
    @PostMapping
    Result add(@Validated @RequestBody SysUser user);
}
