package com.muyu.system.remote.factory;

import com.muyu.common.core.domain.Result;
import com.muyu.common.system.domain.SysDept;
import com.muyu.system.remote.RemoteSysDeptService;
import lombok.extern.log4j.Log4j2;
import org.springframework.cloud.openfeign.FallbackFactory;

/**
 * 远程调用部门熔断器 RemoteSysDeptFactory
 *
 * @author DeKangLiu
 * Date 2024/6/7 09:00
 */
@Log4j2
public class RemoteSysDeptFactory implements FallbackFactory<RemoteSysDeptService> {
    @Override
    public RemoteSysDeptService create(Throwable cause) {

        return new RemoteSysDeptService() {
            /**
             * 查找部门列表
             * @param name
             * @return
             */
            @Override
            public Result<SysDept> selectDeptByName(String name) {
                return Result.error(cause.getMessage());
            }

            /**
             * 添加部门管理
             * @param dept
             * @return
             */
            @Override
            public Result add(SysDept dept) {
                return Result.error(cause.getMessage());
            }
        };
    }
}
